=======
History
=======

.. sectnum:: :start: 4

0.1.0 (2019-03-06)
==================


* First release on PyPI.

0.3.3 (2020-07-25)
==================

* Better treatment of FFT factors
* Lots of new features including bias hardening and isotropic RDN0
